API Reference
=============

This section contains the complete API documentation for all edaflow functions.

.. toctree::
   :maxdepth: 2

   core_functions
   visualization_functions

Complete Function Index
-----------------------

.. currentmodule:: edaflow

**Data Quality & Analysis**

.. autosummary::
   :toctree: generated/

   check_null_columns
   analyze_categorical_columns
   convert_to_numeric
   display_column_types
   summarize_eda_insights

**Data Cleaning & Preprocessing**

.. autosummary::
   :toctree: generated/

   impute_numerical_median
   impute_categorical_mode
   handle_outliers_median

**Visualization & Analysis**

.. autosummary::
   :toctree: generated/

   visualize_categorical_values
   visualize_numerical_boxplots
   visualize_interactive_boxplots
   visualize_heatmap
   visualize_histograms
   visualize_scatter_matrix

**Helper Functions**

.. autosummary::
   :toctree: generated/

   hello
   optimize_display
